@@ -12,11 +12,11 @@ def parallel_gpu_jobs(allow_growth=True, fraction=.5):
     import keras.backend as K
     import tensorflow as tf
 
-    gpu_options = tf.GPUOptions(allow_growth=allow_growth,
+    gpu_options = tf.compat.v1.GPUOptions(allow_growth=allow_growth,
                                   per_process_gpu_memory_fraction=fraction)
-    config = tf.ConfigProto(gpu_options=gpu_options)
-    session = tf.Session(config=config)
-    K.set_session(session)
+    config = tf.compat.v1.ConfigProto(gpu_options=gpu_options)
+    session = tf.compat.v1.Session(config=config)
+    tf.compat.v1.keras.backend.set_session(session)
 
 
 def multi_gpu(model, gpus=None, cpu_merge=True, cpu_relocation=False):
@@ -33,7 +33,7 @@ def multi_gpu(model, gpus=None, cpu_merge=True, cpu_relocation=False):
 
     '''
 
-    from keras.utils import multi_gpu_model
+    from tensorflow.keras.utils import multi_gpu_model
 
     return multi_gpu_model(model,
                            gpus=gpus,
@@ -46,9 +46,9 @@ def force_cpu():
     '''Force CPU on a GPU system
     '''
 
-    import keras.backend as K
+    import tensorflow.keras.backend as K
     import tensorflow as tf
 
-    config = tf.ConfigProto(device_count={'GPU': 0})
-    session = tf.Session(config=config)
-    K.set_session(session)
+    config = tf.compat.v1.ConfigProto(device_count={'GPU': 0})
+    session = tf.compat.v1.Session(config=config)
+    tf.compat.v1.keras.backend.set_session(session)
